@@ -1202,3 +1202,41 @@ class NcmClient:
                                  data=json.dumps(payload))  # Patch indie config with new values
         result = self.__returnhandler(ncm.status_code, ncm.text, call_type)
         return result
+
+    def set_custom1_field_for_router(self, router_id, text):
+        """
+        This method updates the Custom1 field in NCM for a given router id.
+        :param router_id: ID of router to update.
+        :param text: The text to set for the field
+        :return:
+        """
+        call_type = "NCM Field Update"
+
+        puturl = '{0}/routers/{1}/'.format(self.base_url, str(router_id))
+
+        putdata = {
+            "custom1": str(text)
+        }
+
+        ncm = self.session.put(puturl, data=json.dumps(putdata))
+        result = self.__returnhandler(ncm.status_code, ncm.json(), call_type)
+        return result
+
+    def set_custom2_field_for_router(self, router_id, text):
+        """
+        This method updates the Custom2 field in NCM for a given router id.
+        :param router_id: ID of router to update.
+        :param text: The text to set for the field
+        :return:
+        """
+        call_type = "NCM Field Update"
+
+        puturl = '{0}/routers/{1}/'.format(self.base_url, str(router_id))
+
+        putdata = {
+            "custom2": str(text)
+        }
+
+        ncm = self.session.put(puturl, data=json.dumps(putdata))
+        result = self.__returnhandler(ncm.status_code, ncm.json(), call_type)
+        return result
\ No newline at end of file
